.\"                        -*- nroff -*- 
.ig
tmac.5

This is part of groff, the GNU roff type-setting system.

Copyright (C) 2000 Free Software Foundation, Inc.
written by Bernd Warken <bwarken@mayn.de>

Last update: 28 Apr 2000

Permission is granted to copy, distribute and/or modify this document
under the terms of the GNU Free Documentation License, Version 1.1 or
any later version published by the Free Software Foundation; with the
Invariant Sections being "LICENSE TEXT", "AUTHOR", and this unprinted
preface you are reading now, with no Front-Cover Texts, and with no
Back-Cover Texts.

A copy of the Free Documentation License is included as a file called
fdl.txt in the main directory of the groff source package.
..
.\" --------------------------------------------------------------------
.\" Setup
.\" --------------------------------------------------------------------
.de MP
.ds @tmp@ \\fB\\$1\\fP\\fR(\\$2)\\fP
.shift 2
\\*[@tmp@]\\$*
.rm @tmp@
..
.de groffMP
.ds @tmp@ \\fB\\$1\\fP\\fR(@MAN\\$2EXT@)\\fP
.shift 2
\\*[@tmp@]\\$*
.rm @tmp@
..
.de BIR
.ie \\n[.$]<3 .BI $@
.el \{
.ds @tmp@ \\fB\\$1\\fP\\fI\\$2\\fP
.shift 2
\\*[@tmp@]\\fR\\$*\\fP
.rm @tmp@
.\}
..
.ds dquote \&"
.ds dquote \&"\" make Emacs happy
.\" --------------------------------------------------------------------
.\" Title
.\" --------------------------------------------------------------------
.TH TMAC @MAN5EXT@ "@MDATE@" "Groff Version @VERSION@"
.SH NAME
tmac \- macro files in the roff typesetting system
.\" --------------------------------------------------------------------
.SH DESCRIPTION
.\" --------------------------------------------------------------------
The
.groffMP roff 7
type-setting system provides a set of macro packages suitable for
special kinds of documents.  Each macro package stores its macros and
definitions in a file called the package's
.B tmac
.B file .
The name is deduced from
.RB ` T roff
.BR MAC ros'.
.LP
The tmac files are normal roff source documents, except that they
usually contain only definitions and setup commands, but no text.  All
tmac files are kept in a single or a small number of directories, the
.BR tmac directories .
.\" --------------------------------------------------------------------
.SH NAMING
.\" --------------------------------------------------------------------
In classical
.I roff
systems, there was a funny naming scheme.  If the name of a macro
package started with 'm' this letter was omitted, e.g. the macro package
for the man pages
.I man
was called
.I an
and its macro file
.IR tmac.an .
.LP
By a similar reasoning, macro packages that did not start with an 'm'
were often referred to by adding an 'm', e.g. the package corresponding
to
.I tmac.doc
was called
.I mdoc
because the command-line for activating it read
.BIR "troff\ \-m" doc . 
.LP
Actual versions of
.groffMP groff 1
provide both naming schemes for the inflicted macro packages, with and
without the leading 'm'.  So in
.I groff
the
.I man
macro package may be specified as
.BIR "groff\ \-m\ " man ,
.BIR "groff\ \-m" an ,
.BIR "groff\ \-m" man , or
.BIR "groff\ \-m " an .
.LP
The easiest way to find out which macro packages are available on a
system is to check the content of the
.I tmac
.IR directories .
For example, a file called
.I tmac.anything
determines a macro package named
.I anything
or
.IR manything .
.LP
In
.IR groff ,
most macro packages are described in man pages called
.groffMP groff_<name> 7 ,
with a leading
.I m
for the classical packages.
.\" --------------------------------------------------------------------
.SH INCLUSION
.\" --------------------------------------------------------------------
There are several ways to use a macro package in documents.  At
run-time, the groff option
.BI \-m name
makes the definitions in the macro file
.I tmac.name
available as described in the section
.BR NAMING .
.LP
It is also possible to include the macro file into the document by using 
the groff requests
.B .so
or
.BR .mso .
For
.B .so
the full filename of the macro file must be specified including the
directory where it is kept.  If the macro file is stored in one of the
tmac directories it is more convenient to use
.BR .mso
instead because it additionally searches the tmac path for the filename.
.LP
Note that in order to resolve the
.B .so
and
.B .mso
requests the roff preprocessor
.B soelim
must be called.  This can be done either directly by a pipeline on the
command line or by using the option
.B groff \-s
option.
.LP
You can also supply the letter
.B s
in the preprocessor word as described in section
.BR CONVENTION .
.LP
For example, suppose a macro file is stored as
.I /usr/share/groff/tmac/tmac.macros
and is used in some document called
.IR docu.roff .
.LP
At run-time, the formatter call for this is
.B groff
.BI \-m macros
.I docu.roff
.LP
To include the macro file directly in the document either
.LP
.nf
\&\.\e\*[dquote] s
\&\.mso tmac.macros
... text
.fi
.LP
or
.LP
.nf
\&\.\e\*[dquote] s
\&\.so /usr/share/groff/tmac/tmac.macros
... text
.fi
is used.
.LP
In both cases, the formatter is called with
.LP
.B groff\ \-s
.I docu.roff
.\" --------------------------------------------------------------------
.SH CONVENTION
.\" --------------------------------------------------------------------
.LP
There is a convention that is supported by many modern roff
type-setters, the
.B preprocessor word
described in the following.
.LP
If the first line in a document is a comment the first word (after the
comment characters and a blank) constitutes the
.B preprocessor
.BR word .
That means that the letters of this word are interpreted as
abbreviations for tose preprocessor commands that should be run
when formatting the document.  Mostly, only the 4 letters
.BR e ,
.BR p ,
.BR s ,
and
.BR t
are recognized to stand for the classical preprocessors
.BR eqn ,
.BR pic ,
.BR tbl ,
and
.B soelim
resp., see
.groffMP roff 7 .
.LP
Besides being a good reminder for the user, some formatters are even
able to automatically start the preprocessors specified in the
preprocessor word, but do not bet on this.
.\" --------------------------------------------------------------------
.SH "WRITING A MACRO FILE"
.\" --------------------------------------------------------------------
Writing a groff macro file is easy.  Design a set of macros, strings,
registers, etc.  Store them in a single file.  Documents that use the
macros include this macro file with the
.B .so
request as described in the
.B INCLUSION
section.
.LP
To use the tmac functionality, call the macro file
.BI tmac. whatever
and put it in some directory of the tmac path, cf. section
.BR FILES .
Then documents can include it with the
.B .mso
request or the
.B groff -m
option as described in the
.B INCLUSION
section.
.LP
If your macros might be of general usage contact the groff maintainers
to have them included in the groff
.I contrib
source directory.
.LP
Some general guidelines might be helpful in writing macros.
.IP \(bu 2m
Double all functional backslashes,
.RB ` \e '
->
.RB ` \e\e '.
.IP \(bu 2m
All printable backslashes must be written as
.RB ` \ee '.
.IP \(bu 2m
Escape all dots,
.RB ` . '
->
.RB ` \e. '.
.IP \(bu 2m
Make ample use of the non-printable character
.RB ` \e& '
in text parts, esp. before
.RB ` \e '
and at the beginning of a line, but not before a delayed command.
.IP \(bu 2m
Use the character
.RB ` @ '
in temporary variable names.
.IP \(bu 2m
Test your macros for text and graphical devices, e.g.
.I latin1
and
.IR ps .
.\" --------------------------------------------------------------------
.SH FILES
.\" --------------------------------------------------------------------
All macro names that want to use the tmac mechanism must be named
according to the form
.BIR tmac. name .
The macro files are kept in the
.B tmac
.BR directories ,
all of which constitue the
.B tmac
.BR path.
In accordance with the Filesystem Hierarchy Standard (FHS), the standard
tmac directory location for groff is
.IR /usr/share/groff/tmac ,
a local installation will use
.IR /usr/local/share/groff/tmac .
Older systems used a subdirectory of
.IR /usr/lib .
Indendently of the default tmac path, the tmac path actually used by a
document can always be set by a shell environment variable, cf. section
.BR ENVIRONMENT .
.\" --------------------------------------------------------------------
.SH ENVIRONMENT
.\" --------------------------------------------------------------------
.TP
.B GROFF_TMAC_PATH
A colon separated list of tmac directories in which to search for macro
files, the
.B tmac
.BR path .
If unset a default path is used as is outlined in the
.B FILES
section.
.\" --------------------------------------------------------------------
.SH BUGS
.\" --------------------------------------------------------------------
The groff documentation is in evolution at the moment.  It is possible
that small inconsistencies between different documents exist
temporarily.
.\" --------------------------------------------------------------------
.SH AUTHOR
.\" --------------------------------------------------------------------
This document is copyrighted by the Free Software Foundation, was
written by Bernd Warken <bwarken@mayn.de> and may be distributed under
the GNU Free Document License (FDL).
.\" --------------------------------------------------------------------
.SH "SEE ALSO"
.\" --------------------------------------------------------------------
The authoritative source of information for all details of the groff
system is the
.I groff
.MP info 1
file.
.LP
For a groff overview, see
.groffMP roff 7
and the file
.I README
in the groff source package.
.LP
The groff tmac macro packages are
.groffMP groff_man 7 ,
.groffMP groff_markup 7 ,
.groffMP groff_mdoc 7 ,
.groffMP groff_mdoc.samples 7 ,
.groffMP groff_me 7 ,
.groffMP groff_mm 7 ,
.groffMP groff_mmroff 7 ,
.groffMP groff_ms 7 ,
.groffMP groff_msafer 7 .
.LP
The groff language is described in
.groffMP groff 7
and the formatters in
.groffMP groff 1 ,
.groffMP troff 1 .
.LP
The Filesystem Hierarchy Standard (FHS) is available at
.B http://www.pathname.com/fhs/
and the Free Document License at
.BR http://www.gnu.org/copyleft/ .
